@@ -1,4 +1,4 @@
-from exceptions import NoPlayerFoundError
+from .exceptions import NoPlayerFoundError
 from .objects.objects import HypixelPlayer
 import aiohttp
 
