@@ -1,4 +1,4 @@
-from hypixelaPY import utils
+from .. import utils
 
 
 class Bedwars:
